import { __decorate, __param } from 'tslib';
import { forwardRef, EventEmitter, Output, Input, ElementRef, Component, ContentChildren, Optional, NgModule } from '@angular/core';
import { InputMan } from '@grapecity/inputman';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

var GcTextBoxComponent_1, GcNumberComponent_1, GcDateTimeComponent_1, GcMaskComponent_1, GcComboBoxComponent_1, GcMultilineTextBoxComponent_1;
function Property(setter, getter, isPramArr, supportWithinConfig, order) {
    var saveToTargetProDic = function (target, propertyName) {
        var methods = {
            setter: setter,
            getter: getter,
            isPramArr: isPramArr,
            supportWithinConfig: (typeof supportWithinConfig === "boolean") ? supportWithinConfig : true,
            order: (typeof order === "number") ? order : -1
        };
        if (!target.propDic) {
            target.propDic = {};
        }
        target.propDic[propertyName] = methods;
    };
    return saveToTargetProDic;
}
const isEmpty = function (value) {
    return value === undefined || value === null || value === "";
};
const ɵ0 = isEmpty;
const getMethodPrefix = function (type) {
    if (type === MethodType.getter) {
        return "get";
    }
    else if (type === MethodType.setter) {
        return "set";
    }
};
const ɵ1 = getMethodPrefix;
var MethodType;
(function (MethodType) {
    MethodType[MethodType["getter"] = 0] = "getter";
    MethodType[MethodType["setter"] = 1] = "setter";
})(MethodType || (MethodType = {}));
function provideParent(component) {
    return { provide: GcComponents, useExisting: forwardRef(() => component) };
}
class GcComponents {
    constructor(ref) {
        this.onInitialized = new EventEmitter();
        this._container = ref.nativeElement;
    }
    ngOnChanges(changes) {
        if (!this._imCtrl) {
            return;
        }
        Object.keys(changes).forEach((key) => {
            var currentValue = changes[key].currentValue;
            this.setValueToIMControl(key, currentValue);
        });
    }
    setValueToIMControl(key, value) {
        if (value === undefined) {
            return;
        }
        var setter = this.tryGetPropertyOperator(key, MethodType.setter);
        if (this.hasRealMethod(setter)) {
            if (this.propDic && this.propDic[key] && this.propDic[key].isPramArr === true) {
                this._imCtrl[setter].apply(this._imCtrl, value);
            }
            else {
                this._imCtrl[setter](value);
            }
        }
    }
    ngAfterContentInit() {
        this.initGcComponent();
        if (typeof this._imCtrl === 'object') {
            this.onInitialized.emit(this._imCtrl);
        }
        this.bindEvent();
        if (this.propDic) {
            var unSupportWithinConfigProps = Object.keys(this.propDic).filter(p => this.propDic[p] && this.propDic[p].supportWithinConfig === false);
            unSupportWithinConfigProps.sort((p1, p2) => {
                return this.propDic[p1].order - this.propDic[p2].order;
            });
            unSupportWithinConfigProps.forEach(p => {
                this.setValueToIMControl(p, this[p]);
            });
        }
    }
    tryGetPropertyOperator(propertyName, methodType) {
        var method = "";
        if (this.propDic && this.propDic[propertyName]) {
            method = methodType === MethodType.getter ? this.propDic[propertyName].getter : this.propDic[propertyName].setter;
            if (!isEmpty(method)) {
                return method;
            }
        }
        return getMethodPrefix(methodType) + propertyName[0].toUpperCase() + propertyName.slice(1);
    }
    hasRealMethod(methodName) {
        return this._imCtrl && typeof this._imCtrl[methodName] === "function";
    }
    getNestedIMControl() {
        return this._imCtrl;
    }
}
__decorate([
    Output()
], GcComponents.prototype, "onInitialized", void 0);
class GcInputManBaseComponent extends GcComponents {
    constructor() {
        super(...arguments);
        this.onEditStatusChanged = new EventEmitter();
        this.onInvalidInput = new EventEmitter();
        this.onKeyExit = new EventEmitter();
        this.onTextChanged = new EventEmitter();
        this.onInput = new EventEmitter();
        this.onFocusOut = new EventEmitter();
        this.onKeyDown = new EventEmitter();
        this.onKeyUp = new EventEmitter();
        this.onSyncValueToOriginalInput = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.textChange = new EventEmitter();
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.onEditStatusChanged((s) => { this.onEditStatusChanged.emit(s); });
        this._imCtrl.onInvalidInput((s) => { this.onInvalidInput.emit(s); });
        this._imCtrl.onKeyExit((s) => { this.onKeyExit.emit(s); });
        this._imCtrl.onTextChanged((s) => { this.onTextChanged.emit(s); this.textChange.emit(s.getText()); });
        this._imCtrl.onInput((s) => { this.onInput.emit(s); });
        this._imCtrl.onFocusOut((s, e) => { this.onFocusOut.emit({ sender: s, eArgs: e }); });
        this._imCtrl.onKeyDown((s, e) => { this.onKeyDown.emit({ sender: s, eArgs: e }); });
        this._imCtrl.onKeyUp((s, e) => { this.onKeyUp.emit({ sender: s, eArgs: e }); });
        this._imCtrl.onSyncValueToOriginalInput((v, e) => { this.onSyncValueToOriginalInput.emit({ value: v, element: e }); });
    }
}
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "visible", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "enabled", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "readOnly", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "exitOnLeftRightKey", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "editMode", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "watermarkDisplayNullText", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "watermarkNullText", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "acceptsCrlf", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "useClipboard", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "exitOnEnterKey", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "container", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "autoDropDown", void 0);
__decorate([
    Input()
], GcInputManBaseComponent.prototype, "dropDownButtonVisible", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "onEditStatusChanged", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "onInvalidInput", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "onKeyExit", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "onTextChanged", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "onInput", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "onFocusOut", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "onKeyDown", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "onKeyUp", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "onSyncValueToOriginalInput", void 0);
__decorate([
    Output()
], GcInputManBaseComponent.prototype, "textChange", void 0);
let GcTextBoxComponent = GcTextBoxComponent_1 = class GcTextBoxComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onIMEReadingStringOutput = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.imeReadingStringChange = new EventEmitter();
    }
    initGcComponent() {
        var input = document.createElement("input");
        this._container.appendChild(input);
        this["IMEReadingStringAppend"] = this.imeReadingStringAppend;
        this["IMEReadingStringKanaMode"] = this.imeReadingStringKanaMode;
        this["IMEReadingStringEnableAlphabetReadingMapping"] = this.imeReadingStringEnableAlphabetReadingMapping;
        this._imCtrl = new InputMan.GcTextBox(input, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onIMEReadingStringOutput((s, e) => {
            this.onIMEReadingStringOutput.emit({ sender: s, eArgs: e });
            this.imeReadingStringChange.emit(s.getIMEReadingString());
        });
    }
};
GcTextBoxComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input()
], GcTextBoxComponent.prototype, "autoConvert", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "ellipsisString", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "ellipsis", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "format", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "lengthAsByte", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "maxLength", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "passwordChar", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "text", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "useSystemPasswordChar", void 0);
__decorate([
    Input(),
    Property("setIMEReadingStringAppend")
], GcTextBoxComponent.prototype, "imeReadingStringAppend", void 0);
__decorate([
    Input(),
    Property("setIMEReadingStringKanaMode")
], GcTextBoxComponent.prototype, "imeReadingStringKanaMode", void 0);
__decorate([
    Input(),
    Property("setIMEReadingStringEnableAlphabetReadingMapping")
], GcTextBoxComponent.prototype, "imeReadingStringEnableAlphabetReadingMapping", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "exitOnLastChar", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "highlightText", void 0);
__decorate([
    Input()
], GcTextBoxComponent.prototype, "imeReadingString", void 0);
__decorate([
    Output()
], GcTextBoxComponent.prototype, "onIMEReadingStringOutput", void 0);
__decorate([
    Output()
], GcTextBoxComponent.prototype, "imeReadingStringChange", void 0);
GcTextBoxComponent = GcTextBoxComponent_1 = __decorate([
    Component({
        selector: 'gc-text-box',
        template: ``,
        providers: [provideParent(GcTextBoxComponent_1)]
    })
], GcTextBoxComponent);
let GcNumberComponent = GcNumberComponent_1 = class GcNumberComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onSpinDown = new EventEmitter();
        this.onSpinUp = new EventEmitter();
        this.onInvalidRange = new EventEmitter();
        this.onValueChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.valueChange = new EventEmitter();
    }
    initGcComponent() {
        var element = document.createElement('input');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcNumber(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onSpinDown((s) => { this.onSpinDown.emit(s); });
        this._imCtrl.onSpinUp((s) => { this.onSpinUp.emit(s); });
        this._imCtrl.onInvalidRange((s) => { this.onInvalidRange.emit(s); });
        this._imCtrl.onValueChanged((s) => {
            this.onValueChanged.emit(s);
            this.valueChange.emit(s.getValue());
        });
    }
    clear() {
        return this._imCtrl.clear();
    }
};
GcNumberComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input()
], GcNumberComponent.prototype, "value", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "text", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "watermarkZeroText", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "formatDigit", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "displayPositivePrefix", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "displayFormatDigit", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "maxValue", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "minValue", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "positivePrefix", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "positiveSuffix", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "displayPositiveSuffix", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "negativePrefix", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "displayNegativePrefix", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "negativeSuffix", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "displayNegativeSuffix", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "valueSign", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "adjustValueOnFocus", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "allowDeleteToNull", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "clearAction", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "acceptsDecimal", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "currencySymbol", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "decimalPoint", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "maxMinBehavior", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "separator", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "watermarkDisplayZeroText", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "highlightText", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "allowSpin", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "spinOnKeys", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "spinWrap", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "showSpinButton", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "spinButtonPosition", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "showNumericPad", void 0);
__decorate([
    Input()
], GcNumberComponent.prototype, "numericPadPosition", void 0);
__decorate([
    Output()
], GcNumberComponent.prototype, "onSpinDown", void 0);
__decorate([
    Output()
], GcNumberComponent.prototype, "onSpinUp", void 0);
__decorate([
    Output()
], GcNumberComponent.prototype, "onInvalidRange", void 0);
__decorate([
    Output()
], GcNumberComponent.prototype, "onValueChanged", void 0);
__decorate([
    Output()
], GcNumberComponent.prototype, "valueChange", void 0);
GcNumberComponent = GcNumberComponent_1 = __decorate([
    Component({
        selector: 'gc-number',
        template: ``,
        providers: [provideParent(GcNumberComponent_1)]
    })
], GcNumberComponent);
let GcDateTimeComponent = GcDateTimeComponent_1 = class GcDateTimeComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onSpinDown = new EventEmitter();
        this.onSpinUp = new EventEmitter();
        this.onInvalidRange = new EventEmitter();
        this.onInvalidValue = new EventEmitter();
        this.onNumberChanged = new EventEmitter();
        this.onValueChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.numberChange = new EventEmitter();
        this.valueChange = new EventEmitter();
    }
    initGcComponent() {
        var element = document.createElement('input');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcDateTime(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onSpinDown((s) => { this.onSpinDown.emit(s); });
        this._imCtrl.onSpinUp((s) => { this.onSpinUp.emit(s); });
        this._imCtrl.onInvalidRange((s) => { this.onInvalidRange.emit(s); });
        this._imCtrl.onInvalidValue((s) => { this.onInvalidValue.emit(s); });
        this._imCtrl.onNumberChanged((s) => {
            this.onNumberChanged.emit(s);
            this.numberChange.emit(s.getNumber());
        });
        this._imCtrl.onValueChanged((s) => {
            this.onValueChanged.emit(s);
            this.valueChange.emit(s.getValue());
        });
    }
};
GcDateTimeComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input()
], GcDateTimeComponent.prototype, "text", void 0);
__decorate([
    Property("", "", false, false),
    Input()
], GcDateTimeComponent.prototype, "number", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "maxDate", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "minDate", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "formatPattern", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "spinIncrement", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "spinOnKeys", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "spinWrap", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "allowSpin", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "displayFormatPattern", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "watermarkEmptyEraText", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "promptChar", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "AMDesignator", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "PMDesignator", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "twoDigitYearMax", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "hour12Mode", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "tabAction", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "maxMinBehavior", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "midnightAs24", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "showLiterals", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "adjustValueOnFocus", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "useTwoDigitYearMax", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "validateMode", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "clipContent", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "value", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "watermarkDisplayEmptyEraText", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "dropDownConfig", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "exitOnLastChar", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "highlightText", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "showSpinButton", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "spinButtonPosition", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "showDropDownButton", void 0);
__decorate([
    Input()
], GcDateTimeComponent.prototype, "dropDownButtonAlignment", void 0);
__decorate([
    Output()
], GcDateTimeComponent.prototype, "onSpinDown", void 0);
__decorate([
    Output()
], GcDateTimeComponent.prototype, "onSpinUp", void 0);
__decorate([
    Output()
], GcDateTimeComponent.prototype, "onInvalidRange", void 0);
__decorate([
    Output()
], GcDateTimeComponent.prototype, "onInvalidValue", void 0);
__decorate([
    Output()
], GcDateTimeComponent.prototype, "onNumberChanged", void 0);
__decorate([
    Output()
], GcDateTimeComponent.prototype, "onValueChanged", void 0);
__decorate([
    Output()
], GcDateTimeComponent.prototype, "numberChange", void 0);
__decorate([
    Output()
], GcDateTimeComponent.prototype, "valueChange", void 0);
GcDateTimeComponent = GcDateTimeComponent_1 = __decorate([
    Component({
        selector: 'gc-datetime',
        template: ``,
        providers: [provideParent(GcDateTimeComponent_1)]
    })
], GcDateTimeComponent);
let GcCalendarComponent = class GcCalendarComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.onClickDate = new EventEmitter();
        this.onScrolled = new EventEmitter();
        this.onFocusDateChanged = new EventEmitter();
        this.onSelectedDateChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.focusDateChange = new EventEmitter();
        this.selectedDateChange = new EventEmitter();
    }
    initGcComponent() {
        var element = document.createElement('div');
        this._container.appendChild(element);
        if (Array.isArray(this.calendarDimensions)) {
            this.calendarDimensions = {
                width: this.calendarDimensions[0],
                height: this.calendarDimensions[1]
            };
        }
        this._imCtrl = new InputMan.GcCalendar(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.onClickDate((s) => { this.onClickDate.emit(s); });
        this._imCtrl.onScrolled((s) => { this.onScrolled.emit(s); });
        this._imCtrl.onFocusDateChanged((s) => {
            this.onFocusDateChanged.emit(s);
            this.focusDateChange.emit(s.getFocusDate());
        });
        this._imCtrl.onSelectedDateChanged((s) => {
            this.onSelectedDateChanged.emit(s);
            this.selectedDateChange.emit(s.getSelectedDate());
        });
    }
};
GcCalendarComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input()
], GcCalendarComponent.prototype, "visible", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "maxSelectionCount", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "selectionMode", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "selectedDate", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "enabled", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "weekTitleSelect", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "weekNumberSelect", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "focusDate", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "maxDate", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "minDate", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "allowSelection", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "emptyRows", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "firstDayOfWeek", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "firstFiscalMonth", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "firstMonthInView", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "yearMonthFormat", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "headerFormat", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "showZoomButton", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "showRokuyou", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "showHeader", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "showToday", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "showWeekNumber", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "showTrailing", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "calendarYear", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "showNavigator", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "navigatorOrientation", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "overrideTipText", void 0);
__decorate([
    Input()
], GcCalendarComponent.prototype, "calendarType", void 0);
__decorate([
    Property("setCalendarDimensions", "", true),
    Input()
], GcCalendarComponent.prototype, "calendarDimensions", void 0);
__decorate([
    Output()
], GcCalendarComponent.prototype, "onClickDate", void 0);
__decorate([
    Output()
], GcCalendarComponent.prototype, "onScrolled", void 0);
__decorate([
    Output()
], GcCalendarComponent.prototype, "onFocusDateChanged", void 0);
__decorate([
    Output()
], GcCalendarComponent.prototype, "onSelectedDateChanged", void 0);
__decorate([
    Output()
], GcCalendarComponent.prototype, "focusDateChange", void 0);
__decorate([
    Output()
], GcCalendarComponent.prototype, "selectedDateChange", void 0);
GcCalendarComponent = __decorate([
    Component({
        selector: 'gc-calendar',
        template: ``
    })
], GcCalendarComponent);
let GcMaskComponent = GcMaskComponent_1 = class GcMaskComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onTextChanging = new EventEmitter();
        this.onSpinDown = new EventEmitter();
        this.onSpinUp = new EventEmitter();
        this.onValueChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.valueChange = new EventEmitter();
        this.valueIsFullChange = new EventEmitter();
    }
    initGcComponent() {
        var input = document.createElement('input');
        this._container.appendChild(input);
        this._imCtrl = new InputMan.GcMask(input, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onInput((s) => {
            this.valueIsFullChange.emit(s.getValueIsFull());
        });
        this._imCtrl.onTextChanging((s, e) => { this.onTextChanging.emit({ sender: s, eArgs: e }); });
        this._imCtrl.onSpinDown((s) => { this.onSpinDown.emit(s); });
        this._imCtrl.onSpinUp((s) => { this.onSpinUp.emit(s); });
        this._imCtrl.onValueChanged((s) => {
            this.onValueChanged.emit(s);
            this.valueChange.emit(s.getValue());
            this.valueIsFullChange.emit(s.getValueIsFull());
        });
    }
};
GcMaskComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input()
], GcMaskComponent.prototype, "autoConvert", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "value", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "formatPattern", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "promptChar", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "showLiterals", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "tabAction", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "text", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "clipContent", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "allowSpin", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "exitOnLastChar", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "highlightText", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "showSpinButton", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "spinButtonPosition", void 0);
__decorate([
    Input()
], GcMaskComponent.prototype, "valueIsFull", void 0);
__decorate([
    Output()
], GcMaskComponent.prototype, "onTextChanging", void 0);
__decorate([
    Output()
], GcMaskComponent.prototype, "onSpinDown", void 0);
__decorate([
    Output()
], GcMaskComponent.prototype, "onSpinUp", void 0);
__decorate([
    Output()
], GcMaskComponent.prototype, "onValueChanged", void 0);
__decorate([
    Output()
], GcMaskComponent.prototype, "valueChange", void 0);
__decorate([
    Output()
], GcMaskComponent.prototype, "valueIsFullChange", void 0);
GcMaskComponent = GcMaskComponent_1 = __decorate([
    Component({
        selector: 'gc-mask',
        template: ``,
        providers: [provideParent(GcMaskComponent_1)]
    })
], GcMaskComponent);
let GcListBoxColumnComponent = class GcListBoxColumnComponent {
};
__decorate([
    Input()
], GcListBoxColumnComponent.prototype, "name", void 0);
__decorate([
    Input()
], GcListBoxColumnComponent.prototype, "label", void 0);
__decorate([
    Input()
], GcListBoxColumnComponent.prototype, "width", void 0);
__decorate([
    Input()
], GcListBoxColumnComponent.prototype, "isValuePath", void 0);
__decorate([
    Input()
], GcListBoxColumnComponent.prototype, "visible", void 0);
__decorate([
    Input()
], GcListBoxColumnComponent.prototype, "clickSort", void 0);
__decorate([
    Input()
], GcListBoxColumnComponent.prototype, "contentAlignment", void 0);
__decorate([
    Input()
], GcListBoxColumnComponent.prototype, "headerAlignment", void 0);
GcListBoxColumnComponent = __decorate([
    Component({
        selector: 'gc-list-box-column',
        template: ``
    })
], GcListBoxColumnComponent);
let GcListBoxComponent = class GcListBoxComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.checkedChanged = new EventEmitter();
        this.selectedChanged = new EventEmitter();
        this.focusedChanged = new EventEmitter();
        this.itemClick = new EventEmitter();
        this.loadComplete = new EventEmitter();
        this.itemsChanged = new EventEmitter();
        this.selectedIndexChange = new EventEmitter();
        this.checkedIndexChange = new EventEmitter();
        this.selectedIndicesChange = new EventEmitter();
        this.checkedIndicesChange = new EventEmitter();
    }
    initGcComponent() {
        if (this.columnComponents && this.columnComponents.length > 0) {
            this.columns = [];
            this.columnComponents.forEach((column) => {
                this.columns.push({
                    name: column.name,
                    label: column.label,
                    width: column.width,
                    isValuePath: column.isValuePath,
                    visible: column.visible,
                    clickSort: column.clickSort,
                    contentAlignment: column.contentAlignment,
                    headerAlignment: column.headerAlignment
                });
            });
        }
        var element = document.createElement('select');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcListBox(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.CheckedChanged, (eventArgs) => {
            this.checkedChanged.emit(eventArgs);
            this.checkedIndexChange.emit(this._imCtrl.getCheckedIndices()[0]);
            this.checkedIndicesChange.emit(this._imCtrl.getCheckedIndices());
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.SelectedChanged, (eventArgs) => {
            this.selectedChanged.emit(eventArgs);
            this.selectedIndexChange.emit(this._imCtrl.getSelectedIndex());
            this.selectedIndicesChange.emit(this._imCtrl.getSelectedIndices());
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.FocusedChanged, (eventArgs) => {
            this.focusedChanged.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.ItemClick, (sender, eventArgs) => {
            this.itemClick.emit({ sender: sender, eArgs: eventArgs });
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.LoadComplete, (eventArgs) => {
            this.loadComplete.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.ItemsChanged, (eventArgs) => {
            this.itemsChanged.emit(eventArgs);
        });
    }
};
GcListBoxComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input()
], GcListBoxComponent.prototype, "items", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "columns", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "virtualMode", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "allowResize", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "selectionMode", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcListBoxComponent.prototype, "selectedIndex", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcListBoxComponent.prototype, "checkedIndex", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcListBoxComponent.prototype, "selectedIndices", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcListBoxComponent.prototype, "checkedIndices", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "allowColumnResize", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "overflow", void 0);
__decorate([
    Property("resizeWidth"),
    Input()
], GcListBoxComponent.prototype, "width", void 0);
__decorate([
    Property("resizeHeight"),
    Input()
], GcListBoxComponent.prototype, "height", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "itemHeight", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "checkOnClick", void 0);
__decorate([
    Property('setVisibleItemCount'),
    Input()
], GcListBoxComponent.prototype, "visibleItems", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "visible", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "enabled", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "multiColumn", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "colHeaderHeight", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "showHeader", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "valueMemberPath", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "displayMemberPath", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "showCheckBox", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "itemTemplate", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "headerTemplate", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "footerTemplate", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "load", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "pageSize", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "generatingItem", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "selectTemplate", void 0);
__decorate([
    Input()
], GcListBoxComponent.prototype, "formatItem", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "checkedChanged", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "selectedChanged", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "focusedChanged", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "itemClick", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "loadComplete", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "itemsChanged", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "selectedIndexChange", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "checkedIndexChange", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "selectedIndicesChange", void 0);
__decorate([
    Output()
], GcListBoxComponent.prototype, "checkedIndicesChange", void 0);
__decorate([
    ContentChildren(GcListBoxColumnComponent)
], GcListBoxComponent.prototype, "columnComponents", void 0);
GcListBoxComponent = __decorate([
    Component({
        selector: 'gc-list-box',
        template: ``
    })
], GcListBoxComponent);
let GcComboBoxColumnComponent = class GcComboBoxColumnComponent {
};
__decorate([
    Input()
], GcComboBoxColumnComponent.prototype, "name", void 0);
__decorate([
    Input()
], GcComboBoxColumnComponent.prototype, "label", void 0);
__decorate([
    Input()
], GcComboBoxColumnComponent.prototype, "width", void 0);
__decorate([
    Input()
], GcComboBoxColumnComponent.prototype, "isValuePath", void 0);
__decorate([
    Input()
], GcComboBoxColumnComponent.prototype, "visible", void 0);
__decorate([
    Input()
], GcComboBoxColumnComponent.prototype, "clickSort", void 0);
__decorate([
    Input()
], GcComboBoxColumnComponent.prototype, "contentAlignment", void 0);
__decorate([
    Input()
], GcComboBoxColumnComponent.prototype, "headerAlignment", void 0);
GcComboBoxColumnComponent = __decorate([
    Component({
        selector: 'gc-combo-box-column',
        template: ``
    })
], GcComboBoxColumnComponent);
let GcComboBoxComponent = GcComboBoxComponent_1 = class GcComboBoxComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.selectedChanged = new EventEmitter();
        this.checkedChanged = new EventEmitter();
        this.dropDownClosed = new EventEmitter();
        this.dropDownOpened = new EventEmitter();
        this.textChanged = new EventEmitter();
        this.spinDown = new EventEmitter();
        this.spinUp = new EventEmitter();
        this.itemsChanged = new EventEmitter();
        this.itemsChange = new EventEmitter();
        this.selectedValueChange = new EventEmitter();
        this.selectedIndexChange = new EventEmitter();
        this.checkedValuesChange = new EventEmitter();
        this.selectedItemChange = new EventEmitter();
        this.checkedItemsChange = new EventEmitter();
        this.checkedIndicesChange = new EventEmitter();
    }
    initGcComponent() {
        if (this.columnComponents && this.columnComponents.length > 0) {
            this.columns = [];
            this.columnComponents.forEach((column) => {
                this.columns.push({
                    name: column.name,
                    label: column.label,
                    width: column.width,
                    isValuePath: column.isValuePath,
                    visible: column.visible,
                    clickSort: column.clickSort,
                    contentAlignment: column.contentAlignment,
                    headerAlignment: column.headerAlignment
                });
            });
        }
        var element = document.createElement('select');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcComboBox(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.SelectedChanged, (eventArgs) => {
            this.selectedChanged.emit(eventArgs);
            this.selectedValueChange.emit(this._imCtrl.getSelectedValue());
            this.selectedIndexChange.emit(this._imCtrl.getSelectedIndex());
            this.selectedItemChange.emit(this._imCtrl.getSelectedItem());
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.CheckedChanged, (eventArgs) => {
            this.checkedChanged.emit(eventArgs);
            this.checkedValuesChange.emit(this._imCtrl.getCheckedValues());
            this.checkedItemsChange.emit(this._imCtrl.getCheckedItems());
            this.checkedIndicesChange.emit(this._imCtrl.getCheckedIndices());
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.DropDownClosed, (eventArgs) => {
            this.dropDownClosed.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.DropDownOpened, (eventArgs) => {
            this.dropDownOpened.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.TextChanged, (eventArgs) => {
            this.textChanged.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.SpinDown, (eventArgs) => {
            this.spinDown.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.SpinUp, (eventArgs) => {
            this.spinUp.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.ItemsChanged, (eventArgs) => {
            this.itemsChanged.emit(eventArgs);
            this.itemsChange.emit(this._imCtrl.getItems());
        });
    }
};
GcComboBoxComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input()
], GcComboBoxComponent.prototype, "items", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcComboBoxComponent.prototype, "selectedValue", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "allowDropDownResize", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "readOnly", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "autoSelect", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcComboBoxComponent.prototype, "selectedIndex", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "autoFilter", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "visible", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "enabled", void 0);
__decorate([
    Property("setEditable"),
    Input()
], GcComboBoxComponent.prototype, "isEditable", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "watermarkDisplayNullText", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "watermarkNullText", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "highlightText", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "exitOnEnterKey", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "useClipboard", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "acceptsCrlf", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "ellipsis", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "ellipsisString", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "exitOnLeftRightKey", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "editMode", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcComboBoxComponent.prototype, "checkedValues", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcComboBoxComponent.prototype, "selectedItem", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcComboBoxComponent.prototype, "checkedItems", void 0);
__decorate([
    Input(),
    Property("", "", false, false)
], GcComboBoxComponent.prototype, "checkedIndices", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "showDropDownButton", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "dropDownButtonPosition", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "showSpinButton", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "spinButtonPosition", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "dropDownWidth", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "dropDownHeight", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "minPrefixLength", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "isMultiSelect", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "dropDownOverflow", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "visibleItems", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "itemHeight", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "columns", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "showHeader", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "valueMemberPath", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "displayMemberPath", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "checkOnClick", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "itemTemplate", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "headerTemplate", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "footerTemplate", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "load", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "pageSize", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "virtualMode", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "generatingItem", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "selectTemplate", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "formatItem", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "allowColumnResize", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "colHeaderHeight", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "container", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "autoDropDown", void 0);
__decorate([
    Input()
], GcComboBoxComponent.prototype, "dropDownButtonVisible", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "selectedChanged", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "checkedChanged", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "dropDownClosed", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "dropDownOpened", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "textChanged", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "spinDown", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "spinUp", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "itemsChanged", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "itemsChange", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "selectedValueChange", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "selectedIndexChange", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "checkedValuesChange", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "selectedItemChange", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "checkedItemsChange", void 0);
__decorate([
    Output()
], GcComboBoxComponent.prototype, "checkedIndicesChange", void 0);
__decorate([
    ContentChildren(GcComboBoxColumnComponent)
], GcComboBoxComponent.prototype, "columnComponents", void 0);
GcComboBoxComponent = GcComboBoxComponent_1 = __decorate([
    Component({
        selector: 'gc-combo-box',
        template: ``,
        providers: [provideParent(GcComboBoxComponent_1)]
    })
], GcComboBoxComponent);
let GcDateTimePickerComponent = class GcDateTimePickerComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.selectedDateChanged = new EventEmitter();
        this.selectedValueChange = new EventEmitter();
    }
    initGcComponent() {
        var element = document.createElement('div');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcDateTimePicker(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.addEventListener(InputMan.GcDateTimePickerEvent.SelectedDateChanged, (sender, eventArgs) => {
            this.selectedDateChanged.emit({ sender: sender, eArgs: eventArgs });
            this.selectedValueChange.emit(this._imCtrl.getValue());
        });
    }
};
GcDateTimePickerComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Property("setValue"),
    Input()
], GcDateTimePickerComponent.prototype, "selectedValue", void 0);
__decorate([
    Input()
], GcDateTimePickerComponent.prototype, "maxDate", void 0);
__decorate([
    Input()
], GcDateTimePickerComponent.prototype, "minDate", void 0);
__decorate([
    Property('setPickerType'),
    Input()
], GcDateTimePickerComponent.prototype, "type", void 0);
__decorate([
    Input()
], GcDateTimePickerComponent.prototype, "minuteInterval", void 0);
__decorate([
    Input()
], GcDateTimePickerComponent.prototype, "secondsInterval", void 0);
__decorate([
    Input()
], GcDateTimePickerComponent.prototype, "visible", void 0);
__decorate([
    Property('showSeconds', "", false, false),
    Input()
], GcDateTimePickerComponent.prototype, "hasSeconds", void 0);
__decorate([
    Property('showMidnightAs24', "", false, false),
    Input()
], GcDateTimePickerComponent.prototype, "showMidnightAs24", void 0);
__decorate([
    Input()
], GcDateTimePickerComponent.prototype, "yearFormat", void 0);
__decorate([
    Input()
], GcDateTimePickerComponent.prototype, "monthFormat", void 0);
__decorate([
    Input()
], GcDateTimePickerComponent.prototype, "dayFormat", void 0);
__decorate([
    Output()
], GcDateTimePickerComponent.prototype, "selectedDateChanged", void 0);
__decorate([
    Output()
], GcDateTimePickerComponent.prototype, "selectedValueChange", void 0);
GcDateTimePickerComponent = __decorate([
    Component({
        selector: 'gc-datetime-picker',
        template: ``
    })
], GcDateTimePickerComponent);
let GcTipNotifierComponent = class GcTipNotifierComponent extends GcComponents {
    constructor(ref, _parent) {
        super(ref);
        this._parent = _parent;
    }
    ngAfterViewInit() {
        if (!this._parent || typeof this._parent !== 'object' ||
            typeof this._parent.getNestedIMControl() !== 'object') {
            return;
        }
        this._imCtrl = new InputMan.GcTipNotifier(this._parent.getNestedIMControl(), this);
        this.onInitialized.emit(this._imCtrl);
    }
    bindEvent() { }
    initGcComponent() {
    }
    onFail() {
        return this._imCtrl.onFail();
    }
    onSuccess() {
        return this._imCtrl.onSuccess();
    }
    onClear() {
        return this._imCtrl.onClear();
    }
};
GcTipNotifierComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: GcComponents, decorators: [{ type: Optional }] }
];
__decorate([
    Input()
], GcTipNotifierComponent.prototype, "direction", void 0);
__decorate([
    Input()
], GcTipNotifierComponent.prototype, "position", void 0);
__decorate([
    Input()
], GcTipNotifierComponent.prototype, "directionPriority", void 0);
__decorate([
    Input()
], GcTipNotifierComponent.prototype, "template", void 0);
__decorate([
    Input()
], GcTipNotifierComponent.prototype, "failMessage", void 0);
__decorate([
    Input()
], GcTipNotifierComponent.prototype, "successMessage", void 0);
__decorate([
    Input()
], GcTipNotifierComponent.prototype, "tipState", void 0);
GcTipNotifierComponent = __decorate([
    Component({
        selector: 'gc-tip-notifier',
        template: ``
    }),
    __param(1, Optional())
], GcTipNotifierComponent);
let GcIconNotifierComponent = class GcIconNotifierComponent extends GcComponents {
    constructor(ref, _parent) {
        super(ref);
        this._parent = _parent;
    }
    ngAfterViewInit() {
        if (!this._parent || typeof this._parent !== 'object' ||
            typeof this._parent.getNestedIMControl() !== 'object') {
            return;
        }
        this._imCtrl = new InputMan.GcIconNotifier(this._parent.getNestedIMControl(), this);
        this.onInitialized.emit(this._imCtrl);
    }
    bindEvent() { }
    initGcComponent() {
    }
    onFail() {
        return this._imCtrl.onFail();
    }
    onSuccess() {
        return this._imCtrl.onSuccess();
    }
    onClear() {
        return this._imCtrl.onClear();
    }
};
GcIconNotifierComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: GcComponents, decorators: [{ type: Optional }] }
];
__decorate([
    Input()
], GcIconNotifierComponent.prototype, "direction", void 0);
__decorate([
    Property('setFailIconSrc'),
    Input()
], GcIconNotifierComponent.prototype, "failIcon", void 0);
__decorate([
    Property('setSuccessIconSrc'),
    Input()
], GcIconNotifierComponent.prototype, "successIcon", void 0);
__decorate([
    Input()
], GcIconNotifierComponent.prototype, "failMessage", void 0);
__decorate([
    Input()
], GcIconNotifierComponent.prototype, "successMessage", void 0);
GcIconNotifierComponent = __decorate([
    Component({
        selector: 'gc-icon-notifier',
        template: ``
    }),
    __param(1, Optional())
], GcIconNotifierComponent);
let GcMultilineTextBoxComponent = GcMultilineTextBoxComponent_1 = class GcMultilineTextBoxComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onEditStatusChanged = new EventEmitter();
        this.onInvalidInput = new EventEmitter();
        this.onKeyExit = new EventEmitter();
        this.onTextChanged = new EventEmitter();
        this.onIMEReadingStringOutput = new EventEmitter();
        this.textChange = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.imeReadingStringChange = new EventEmitter();
    }
    initGcComponent() {
        var element = document.createElement('textarea');
        this._container.appendChild(element);
        this["IMEReadingStringAppend"] = this.imeReadingStringAppend;
        this["IMEReadingStringKanaMode"] = this.imeReadingStringKanaMode;
        this["IMEReadingStringEnableAlphabetReadingMapping"] = this.imeReadingStringEnableAlphabetReadingMapping;
        this._imCtrl = new InputMan.GcMultiLineTextBox(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onIMEReadingStringOutput((eventArgs) => {
            this.onIMEReadingStringOutput.emit(eventArgs);
            this.imeReadingStringChange.emit(this._imCtrl.getIMEReadingString());
        });
    }
};
GcMultilineTextBoxComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "countWrappedLine", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "lengthAsByte", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "maxLength", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "maxLineCount", void 0);
__decorate([
    Input(),
    Property("setIMEReadingStringKanaMode")
], GcMultilineTextBoxComponent.prototype, "imeReadingStringKanaMode", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "scrollBarMode", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "scrollBars", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "wordWrap", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "acceptsReturn", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "acceptsTab", void 0);
__decorate([
    Input(),
    Property("setIMEReadingStringAppend")
], GcMultilineTextBoxComponent.prototype, "imeReadingStringAppend", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "height", void 0);
__decorate([
    Input(),
    Property("setIMEReadingStringEnableAlphabetReadingMapping")
], GcMultilineTextBoxComponent.prototype, "imeReadingStringEnableAlphabetReadingMapping", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "exitOnLastChar", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "highlightText", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "format", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "autoConvert", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "text", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "lines", void 0);
__decorate([
    Input()
], GcMultilineTextBoxComponent.prototype, "imeReadingString", void 0);
__decorate([
    Output()
], GcMultilineTextBoxComponent.prototype, "onEditStatusChanged", void 0);
__decorate([
    Output()
], GcMultilineTextBoxComponent.prototype, "onInvalidInput", void 0);
__decorate([
    Output()
], GcMultilineTextBoxComponent.prototype, "onKeyExit", void 0);
__decorate([
    Output()
], GcMultilineTextBoxComponent.prototype, "onTextChanged", void 0);
__decorate([
    Output()
], GcMultilineTextBoxComponent.prototype, "onIMEReadingStringOutput", void 0);
__decorate([
    Output()
], GcMultilineTextBoxComponent.prototype, "textChange", void 0);
__decorate([
    Output()
], GcMultilineTextBoxComponent.prototype, "imeReadingStringChange", void 0);
GcMultilineTextBoxComponent = GcMultilineTextBoxComponent_1 = __decorate([
    Component({
        selector: 'gc-multiline-textbox',
        template: ``,
        providers: [provideParent(GcMultilineTextBoxComponent_1)]
    })
], GcMultilineTextBoxComponent);

/**
 *  Declare & add export modules
 */
let InputManModule = class InputManModule {
};
InputManModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule
        ],
        declarations: [
            GcMaskComponent,
            GcTextBoxComponent,
            GcCalendarComponent,
            GcNumberComponent,
            GcDateTimeComponent,
            GcListBoxComponent,
            GcComboBoxComponent,
            GcDateTimePickerComponent,
            GcTipNotifierComponent,
            GcIconNotifierComponent,
            GcMultilineTextBoxComponent,
            GcComboBoxColumnComponent,
            GcListBoxColumnComponent
        ],
        exports: [
            GcMaskComponent,
            GcTextBoxComponent,
            GcCalendarComponent,
            GcNumberComponent,
            GcDateTimeComponent,
            GcListBoxComponent,
            GcComboBoxComponent,
            GcDateTimePickerComponent,
            GcTipNotifierComponent,
            GcIconNotifierComponent,
            GcMultilineTextBoxComponent,
            GcComboBoxColumnComponent,
            GcListBoxColumnComponent
        ]
    })
], InputManModule);

/**
 * Generated bundle index. Do not edit.
 */

export { GcCalendarComponent, GcComboBoxColumnComponent, GcComboBoxComponent, GcComponents, GcDateTimeComponent, GcDateTimePickerComponent, GcIconNotifierComponent, GcInputManBaseComponent, GcListBoxColumnComponent, GcListBoxComponent, GcMaskComponent, GcMultilineTextBoxComponent, GcNumberComponent, GcTextBoxComponent, GcTipNotifierComponent, InputManModule, MethodType, Property, provideParent, ɵ0, ɵ1 };
//# sourceMappingURL=grapecity-inputman.angular.js.map
